@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -36,19 +36,20 @@
 
 #if USE_PKCS11
 #include <pk11/result.h>
-#endif
+#endif /* if USE_PKCS11 */
 
 #include <dns/keyvalues.h>
 #include <dns/name.h>
 #include <dns/result.h>
 
+#include <dst/dst.h>
+
+#include <confgen/os.h>
+
 #include "keygen.h"
 #include "util.h"
 
-#include <confgen/os.h>
-#include <dst/dst.h>
-
-#define KEYGEN_DEFAULT "tsig-key"
+#define KEYGEN_DEFAULT	"tsig-key"
 #define CONFGEN_DEFAULT "ddns-key"
 
 static char program[256];
@@ -60,8 +61,7 @@ ISC_PLATFORM_NORETURN_PRE static void
 usage(int status) ISC_PLATFORM_NORETURN_POST;
 
 static void
-usage(int status)
-{
+usage(int status) {
 	if (progmode == progmode_confgen) {
 		fprintf(stderr, "\
 Usage:\n\
@@ -84,40 +84,41 @@ Usage:\n\
 }
 
 int
-main(int argc, char **argv)
-{
+main(int argc, char **argv) {
 	isc_result_t result = ISC_R_SUCCESS;
-	bool	     show_final_mem = false;
-	bool	     quiet = false;
+	bool show_final_mem = false;
+	bool quiet = false;
 	isc_buffer_t key_txtbuffer;
-	char	     key_txtsecret[256];
-	isc_mem_t *  mctx = NULL;
-	const char * keyname = NULL;
-	const char * zone = NULL;
-	const char * self_domain = NULL;
-	char *	     keybuf = NULL;
+	char key_txtsecret[256];
+	isc_mem_t *mctx = NULL;
+	const char *keyname = NULL;
+	const char *zone = NULL;
+	const char *self_domain = NULL;
+	char *keybuf = NULL;
 	dns_secalg_t alg = DST_ALG_HMACSHA256;
-	const char * algname;
-	int	     keysize = 256;
-	int	     len = 0;
-	int	     ch;
+	const char *algname;
+	int keysize = 256;
+	int len = 0;
+	int ch;
 
 #if USE_PKCS11
 	pk11_result_register();
-#endif
+#endif /* if USE_PKCS11 */
 	dns_result_register();
 
 	result = isc_file_progname(*argv, program, sizeof(program));
-	if (result != ISC_R_SUCCESS)
+	if (result != ISC_R_SUCCESS) {
 		memmove(program, "tsig-keygen", 11);
+	}
 	progname = program;
 
 	/*
 	 * Libtool doesn't preserve the program name prior to final
 	 * installation.  Remove the libtool prefix ("lt-").
 	 */
-	if (strncmp(progname, "lt-", 3) == 0)
+	if (strncmp(progname, "lt-", 3) == 0) {
 		progname += 3;
+	}
 
 #define PROGCMP(X) \
 	(strcasecmp(progname, X) == 0 || strcasecmp(progname, X ".exe") == 0)
@@ -140,18 +141,20 @@ main(int argc, char **argv)
 		case 'a':
 			algname = isc_commandline_argument;
 			alg = alg_fromtext(algname);
-			if (alg == DST_ALG_UNKNOWN)
+			if (alg == DST_ALG_UNKNOWN) {
 				fatal("Unsupported algorithm '%s'", algname);
+			}
 			keysize = alg_bits(alg);
 			break;
 		case 'h':
 			usage(0);
 		case 'k':
 		case 'y':
-			if (progmode == progmode_confgen)
+			if (progmode == progmode_confgen) {
 				keyname = isc_commandline_argument;
-			else
+			} else {
 				usage(1);
+			}
 			break;
 		case 'M':
 			isc_mem_debugging = ISC_MEM_DEBUGTRACE;
@@ -160,33 +163,37 @@ main(int argc, char **argv)
 			show_final_mem = true;
 			break;
 		case 'q':
-			if (progmode == progmode_confgen)
+			if (progmode == progmode_confgen) {
 				quiet = true;
-			else
+			} else {
 				usage(1);
+			}
 			break;
 		case 'r':
 			fatal("The -r option has been deprecated.");
 			break;
 		case 's':
-			if (progmode == progmode_confgen)
+			if (progmode == progmode_confgen) {
 				self_domain = isc_commandline_argument;
-			else
+			} else {
 				usage(1);
+			}
 			break;
 		case 'z':
-			if (progmode == progmode_confgen)
+			if (progmode == progmode_confgen) {
 				zone = isc_commandline_argument;
-			else
+			} else {
 				usage(1);
+			}
 			break;
 		case '?':
 			if (isc_commandline_option != '?') {
 				fprintf(stderr, "%s: invalid argument -%c\n",
 					program, isc_commandline_option);
 				usage(1);
-			} else
+			} else {
 				usage(0);
+			}
 			break;
 		default:
 			fprintf(stderr, "%s: unhandled option -%c\n", program,
@@ -195,16 +202,19 @@ main(int argc, char **argv)
 		}
 	}
 
-	if (progmode == progmode_keygen)
+	if (progmode == progmode_keygen) {
 		keyname = argv[isc_commandline_index++];
+	}
 
 	POST(argv);
 
-	if (self_domain != NULL && zone != NULL)
+	if (self_domain != NULL && zone != NULL) {
 		usage(1); /* -s and -z cannot coexist */
+	}
 
-	if (argc > isc_commandline_index)
+	if (argc > isc_commandline_index) {
 		usage(1);
+	}
 
 	/* Use canonical algorithm name */
 	algname = alg_totext(alg);
@@ -216,10 +226,11 @@ main(int argc, char **argv)
 
 		keyname = ((progmode == progmode_keygen) ? KEYGEN_DEFAULT
 							 : CONFGEN_DEFAULT);
-		if (self_domain != NULL)
+		if (self_domain != NULL) {
 			suffix = self_domain;
-		else if (zone != NULL)
+		} else if (zone != NULL) {
 			suffix = zone;
+		}
 		if (suffix != NULL) {
 			len = strlen(keyname) + strlen(suffix) + 2;
 			keybuf = isc_mem_get(mctx, len);
@@ -232,11 +243,12 @@ main(int argc, char **argv)
 
 	generate_key(mctx, alg, keysize, &key_txtbuffer);
 
-	if (!quiet)
+	if (!quiet) {
 		printf("\
 # To activate this key, place the following in named.conf, and\n\
 # in a separate keyfile on the system or systems from which nsupdate\n\
 # will be run:\n");
+	}
 
 	printf("\
 key \"%s\" {\n\
@@ -283,11 +295,13 @@ update-policy {\n\
 nsupdate -k <keyfile>\n");
 	}
 
-	if (keybuf != NULL)
+	if (keybuf != NULL) {
 		isc_mem_put(mctx, keybuf, len);
+	}
 
-	if (show_final_mem)
+	if (show_final_mem) {
 		isc_mem_stats(mctx, stderr);
+	}
 
 	isc_mem_destroy(&mctx);
 
