@@ -81,7 +81,7 @@ options {\n\
 	listen-on-v6 {any;};\n\
 #	lock-file \"" NAMED_LOCALSTATEDIR "/run/named/named.lock\";\n\
 	match-mapped-addresses no;\n\
-	max-ixfr-ratio 100%;\n\
+	max-ixfr-ratio unlimited;\n\
 	max-rsa-exponent-size 0; /* no limit */\n\
 	max-udp-size 1232;\n\
 	memstatistics-file \"named.memstats\";\n\
@@ -194,8 +194,8 @@ options {\n\
 	root-key-sentinel yes;\n\
 	servfail-ttl 1;\n\
 #	sortlist <none>\n\
-	stale-answer-enable false;\n\
 	stale-answer-client-timeout off;\n\
+	stale-answer-enable false;\n\
 	stale-answer-ttl 30; /* 30 seconds */\n\
 	stale-cache-enable true;\n\
 	stale-refresh-time 30; /* 30 seconds */\n\
