@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -16,7 +16,7 @@
 
 #ifdef ISC_MAIN_HOOK
 #define main(argc, argv) bindmain(argc, argv)
-#endif
+#endif /* ifdef ISC_MAIN_HOOK */
 
 /*
  * Commandline arguments for named; also referenced in win32/ntservice.c
