@@ -9,11 +9,14 @@
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-rm -f */K* */dsset-* */*.signed */trusted.conf
-rm -f ns1/root.db
-rm -f ns1/signer.err
+rm -f */K* */dsset-* */*.signed
 rm -f dig.out*
-rm -f */named.run
-rm -f */named.memstats
+rm -f ns*/named.run
+rm -f ns*/named.memstats
 rm -f ns*/named.lock
+rm -f ns*/named.conf
 rm -f ns*/managed-keys.bind*
+rm -f ns*/root.db
+rm -f ns*/signer.err
+rm -f ns*/trusted.conf
+rm -f *-supported.file
