@@ -12,10 +12,10 @@
 #
 # Set up a test zone
 #
-# Usage: genzone.sh master-server-number slave-server-number...
+# Usage: genzone.sh master-server-number secondary-server-number...
 #
 # e.g., "genzone.sh 2 3 4" means ns2 is the master and ns3, ns4
-# are slaves.
+# are secondaries.
 #
 
 master="$1"
@@ -369,11 +369,17 @@ csync01			CSYNC	0 0 A NS AAAA
 csync02			CSYNC	0 0
 
 ;type	63
-zonemd01		ZONEMD	2019020700 1 0 (
+zonemd01		ZONEMD	2019020700 1 1 (
                                 C220B8A6ED5728A971902F7E3D4FD93A
                                 DEEA88B0453C2E8E8C863D465AB06CF3
                                 4EB95B266398C98B59124FA239CB7EEB
 				)
+zonemd02		ZONEMD	2019020700 1 2 (
+				08CFA1115C7B948C4163A901270395EA
+			        226A930CD2CBCF2FA9A5E6EB85F37C8A
+                                4E114D884E66F176EAB121CB02DB7D65
+                                2E0CC4827E7A3204F166B47E5613FD27
+				)
 
 ; type 64 -- 98 (unassigned)
 
