@@ -1,19 +1,16 @@
 #!/bin/sh
-
+#
 # Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
-# SPDX-License-Identifier: MPL-2.0
-#
 # This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0.  If a copy of the MPL was not distributed with this
+# License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, you can obtain one at https://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-set -e
-
-. ../conf.sh
+SYSTEMTESTTOP=..
+. $SYSTEMTESTTOP/conf.sh
 
 #
 # Do glue tests.
@@ -28,7 +25,7 @@ $DIG $DIGOPTS @10.53.0.1 foo.bar.fi. A >dig.out || status=1
 digcomp --lc fi.good dig.out || status=1
 
 echo_i "testing that we don't find out-of-zone glue"
-$DIG $DIGOPTS @10.53.0.1 example.net. a >dig.out || status=1
+$DIG $DIGOPTS @10.53.0.1 example.net. a > dig.out || status=1
 digcomp noglue.good dig.out || status=1
 
 echo_i "exit status: $status"
