@@ -1,17 +1,13 @@
-#!/bin/sh
-
 # Copyright (C) Internet Systems Consortium, Inc. ("ISC")
 #
-# SPDX-License-Identifier: MPL-2.0
-#
 # This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0.  If a copy of the MPL was not distributed with this
+# License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, you can obtain one at https://mozilla.org/MPL/2.0/.
 #
 # See the COPYRIGHT file distributed with this work for additional
 # information regarding copyright ownership.
 
-rm -f dig.out*
+rm -f dig.out.test*
 rm -f ns*/named.conf
 rm -f ns*/root.bk
 rm -f rndc.out.test*
