@@ -209,7 +209,7 @@ sub start_server {
 		if (++$tries > 140) {
 			print "I:$test:Couldn't start server $command (pid=$child)\n";
 			print "I:$test:failed\n";
-			system "kill -9 $child" if ("$child" ne "");
+			kill "ABRT", $child if ("$child" ne "");
 			chdir "$testdir";
 			system "$PERL $topdir/stop.pl $test";
 			exit 1;
