@@ -945,6 +945,29 @@ journal_next(dns_journal_t *j, journal_pos_t *pos, bool retry) {
 			  ? sizeof(journal_rawxhdr_t)
 			  : sizeof(journal_rawxhdr_ver1_t);
 
+	/*
+	 * Handle <size, serial0, serial1, 0> transaction header.
+	 */
+	if (j->header_ver1 && j->xhdr_version == XHDR_VERSION1) {
+		uint32_t value;
+
+		CHECK(journal_read(j, &value, sizeof(value)));
+		if (value != 0L) {
+			CHECK(journal_seek(j, pos->offset + 12));
+		} else {
+			j->recovered = true;
+			hdrsize += 4;
+		}
+	} else if (j->header_ver1 && j->xhdr_version == XHDR_VERSION2 &&
+		   xhdr.count == pos->serial && xhdr.serial1 == 0U &&
+		   isc_serial_ge(xhdr.serial0, xhdr.count))
+	{
+		xhdr.serial1 = xhdr.serial0;
+		xhdr.serial0 = xhdr.count;
+		xhdr.count = 0;
+		j->recovered = true;
+	}
+
 	if ((isc_offset_t)(pos->offset + hdrsize + xhdr.size) < pos->offset) {
 		isc_log_write(JOURNAL_COMMON_LOGARGS, ISC_LOG_ERROR,
 			      "%s: offset too large", j->filename);
@@ -954,6 +977,9 @@ journal_next(dns_journal_t *j, journal_pos_t *pos, bool retry) {
 	pos->offset += hdrsize + xhdr.size;
 	pos->serial = xhdr.serial1;
 	return (ISC_R_SUCCESS);
+
+failure:
+	return (result);
 }
 
 /*
@@ -1101,7 +1127,6 @@ isc_result_t
 dns_journal_begin_transaction(dns_journal_t *j) {
 	uint32_t offset;
 	isc_result_t result;
-	journal_rawxhdr_t hdr;
 
 	REQUIRE(DNS_JOURNAL_VALID(j));
 	REQUIRE(j->state == JOURNAL_STATE_WRITE ||
@@ -1128,8 +1153,7 @@ dns_journal_begin_transaction(dns_journal_t *j) {
 	 * space.  It will be filled in when the transaction is
 	 * finished.
 	 */
-	memset(&hdr, 0, sizeof(hdr));
-	CHECK(journal_write(j, &hdr, sizeof(hdr)));
+	CHECK(journal_write_xhdr(j, 0, 0, 0, 0));
 	j->x.pos[1].offset = j->offset;
 
 	j->state = JOURNAL_STATE_TRANSACTION;
@@ -1320,7 +1344,8 @@ dns_journal_commit(dns_journal_t *j) {
 	if (j->state == JOURNAL_STATE_TRANSACTION) {
 		isc_offset_t offset;
 		offset = (j->x.pos[1].offset - j->x.pos[0].offset) -
-			 sizeof(journal_rawxhdr_t);
+			 (j->header_ver1 ? sizeof(journal_rawxhdr_ver1_t)
+					 : sizeof(journal_rawxhdr_t));
 		/*
 		 * Update the transaction header.
 		 */
@@ -1425,8 +1450,8 @@ dns_journal_destroy(dns_journal_t **journalp) {
 
 /* XXX Share code with incoming IXFR? */
 
-static isc_result_t
-roll_forward(dns_journal_t *j, dns_db_t *db, unsigned int options) {
+isc_result_t
+dns_journal_rollforward(dns_journal_t *j, dns_db_t *db, unsigned int options) {
 	isc_buffer_t source; /* Transaction data from disk */
 	isc_buffer_t target; /* Ditto after _fromwire check */
 	uint32_t db_serial;  /* Database SOA serial */
@@ -1572,40 +1597,6 @@ failure:
 	return (result);
 }
 
-isc_result_t
-dns_journal_rollforward(isc_mem_t *mctx, dns_db_t *db, unsigned int options,
-			const char *filename) {
-	dns_journal_t *j = NULL;
-	isc_result_t result;
-
-	REQUIRE(DNS_DB_VALID(db));
-	REQUIRE(filename != NULL);
-
-	result = dns_journal_open(mctx, filename, DNS_JOURNAL_READ, &j);
-	if (result == ISC_R_NOTFOUND) {
-		isc_log_write(JOURNAL_DEBUG_LOGARGS(3), "no journal file, but "
-							"that's OK");
-		return (DNS_R_NOJOURNAL);
-	}
-	if (result != ISC_R_SUCCESS) {
-		return (result);
-	}
-
-	if (JOURNAL_EMPTY(&j->header)) {
-		CHECK(DNS_R_UPTODATE);
-	}
-
-	result = roll_forward(j, db, options);
-	if ((result == ISC_R_SUCCESS || result == DNS_R_UPTODATE) &&
-	    j->recovered) {
-		result = DNS_R_RECOVERABLE;
-	}
-
-failure:
-	dns_journal_destroy(&j);
-	return (result);
-}
-
 isc_result_t
 dns_journal_print(isc_mem_t *mctx, uint32_t flags, const char *filename,
 		  FILE *file) {
@@ -1763,6 +1754,11 @@ dns_journal_empty(dns_journal_t *j) {
 	return (JOURNAL_EMPTY(&j->header));
 }
 
+bool
+dns_journal_recovered(dns_journal_t *j) {
+	return (j->recovered);
+}
+
 uint32_t
 dns_journal_first_serial(dns_journal_t *j) {
 	return (j->header.begin.serial);
@@ -1977,6 +1973,30 @@ read_one_rr(dns_journal_t *j, bool retry) {
 				      xhdr.serial0);
 			FAIL(ISC_R_UNEXPECTED);
 		}
+
+		/*
+		 * Handle <size, serial0, serial1, 0> transaction header.
+		 */
+		if (j->header_ver1 && j->xhdr_version == XHDR_VERSION1) {
+			uint32_t value;
+
+			CHECK(journal_read(j, &value, sizeof(value)));
+			if (value != 0L) {
+				CHECK(journal_seek(j, save.offset + 12));
+			} else {
+				j->recovered = true;
+			}
+		} else if (j->header_ver1 && j->xhdr_version == XHDR_VERSION2 &&
+			   xhdr.count == j->it.current_serial &&
+			   xhdr.serial1 == 0U &&
+			   isc_serial_ge(xhdr.serial0, xhdr.count))
+		{
+			xhdr.serial1 = xhdr.serial0;
+			xhdr.serial0 = xhdr.count;
+			xhdr.count = 0;
+			j->recovered = true;
+		}
+
 		j->it.xsize = xhdr.size;
 		j->it.xpos = 0;
 	}
@@ -2390,7 +2410,7 @@ failure:
 }
 
 static uint32_t
-rrcount(char *buf, unsigned int size) {
+rrcount(unsigned char *buf, unsigned int size) {
 	isc_buffer_t b;
 	uint32_t rrsize, count = 0;
 
@@ -2406,6 +2426,28 @@ rrcount(char *buf, unsigned int size) {
 	return (count);
 }
 
+static bool
+check_delta(unsigned char *buf, size_t size) {
+	isc_buffer_t b;
+	uint32_t rrsize;
+
+	isc_buffer_init(&b, buf, size);
+	isc_buffer_add(&b, size);
+	while (isc_buffer_remaininglength(&b) > 0) {
+		if (isc_buffer_remaininglength(&b) < 4) {
+			return (false);
+		}
+		rrsize = isc_buffer_getuint32(&b);
+		/* "." + type + class + ttl + rdlen => 11U */
+		if (rrsize < 11U || isc_buffer_remaininglength(&b) < rrsize) {
+			return (false);
+		}
+		isc_buffer_forward(&b, rrsize);
+	}
+
+	return (true);
+}
+
 isc_result_t
 dns_journal_compact(isc_mem_t *mctx, char *filename, uint32_t serial,
 		    uint32_t flags, uint32_t target_size) {
@@ -2417,7 +2459,7 @@ dns_journal_compact(isc_mem_t *mctx, char *filename, uint32_t serial,
 	journal_rawheader_t rawheader;
 	unsigned int len;
 	size_t namelen;
-	char *buf = NULL;
+	unsigned char *buf = NULL;
 	unsigned int size = 0;
 	isc_result_t result;
 	unsigned int indexend;
@@ -2451,6 +2493,11 @@ dns_journal_compact(isc_mem_t *mctx, char *filename, uint32_t serial,
 		return (result);
 	}
 
+	/*
+	 * Always perform a re-write when processing a version 1 journal.
+	 */
+	rewrite = j1->header_ver1;
+
 	/*
 	 * Check whether we need to rewrite the whole journal
 	 * file (for example, to upversion it).
@@ -2539,6 +2586,7 @@ dns_journal_compact(isc_mem_t *mctx, char *filename, uint32_t serial,
 	INSIST(best_guess.serial != j1->header.end.serial);
 	if (best_guess.serial != serial) {
 		CHECK(journal_next(j1, &best_guess, false));
+		serial = best_guess.serial;
 	}
 
 	/*
@@ -2574,22 +2622,22 @@ dns_journal_compact(isc_mem_t *mctx, char *filename, uint32_t serial,
 			}
 			CHECK(result);
 
+			size = xhdr.size;
+			buf = isc_mem_get(mctx, size);
+			result = journal_read(j1, buf, size);
+
 			/*
 			 * If we're repairing an outdated journal, the
 			 * xhdr format may be wrong.
 			 */
-			if (rewrite &&
-			    (xhdr.serial0 != serial ||
-			     isc_serial_le(xhdr.serial1, xhdr.serial0)))
-			{
-				if (j1->xhdr_version == XHDR_VERSION2 &&
-				    xhdr.count == serial) {
+			if (rewrite && (result != ISC_R_SUCCESS ||
+					!check_delta(buf, size))) {
+				if (j1->xhdr_version == XHDR_VERSION2) {
 					/* XHDR_VERSION2 -> XHDR_VERSION1 */
 					j1->xhdr_version = XHDR_VERSION1;
 					CHECK(journal_seek(j1, offset));
 					CHECK(journal_read_xhdr(j1, &xhdr));
-				} else if (j1->xhdr_version == XHDR_VERSION1 &&
-					   xhdr.serial1 == serial) {
+				} else if (j1->xhdr_version == XHDR_VERSION1) {
 					/* XHDR_VERSION1 -> XHDR_VERSION2 */
 					j1->xhdr_version = XHDR_VERSION2;
 					CHECK(journal_seek(j1, offset));
@@ -2597,16 +2645,47 @@ dns_journal_compact(isc_mem_t *mctx, char *filename, uint32_t serial,
 				}
 
 				/* Check again */
-				if (xhdr.serial0 != serial ||
-				    isc_serial_le(xhdr.serial1, xhdr.serial0)) {
+				isc_mem_put(mctx, buf, size);
+				size = xhdr.size;
+				buf = isc_mem_get(mctx, size);
+				CHECK(journal_read(j1, buf, size));
+
+				if (!check_delta(buf, size)) {
 					CHECK(ISC_R_UNEXPECTED);
 				}
+			} else {
+				CHECK(result);
 			}
 
-			size = xhdr.size;
-			buf = isc_mem_get(mctx, size);
-			CHECK(journal_read(j1, buf, size));
+			/*
+			 * Recover from incorrectly written transaction header.
+			 * The incorrect header was written as size, serial0,
+			 * serial1, and 0.  XHDR_VERSION2 is expecting size,
+			 * count, serial0, and serial1.
+			 */
+			if (j1->xhdr_version == XHDR_VERSION2 &&
+			    xhdr.count == serial && xhdr.serial1 == 0U &&
+			    isc_serial_ge(xhdr.serial0, xhdr.count))
+			{
+				xhdr.serial1 = xhdr.serial0;
+				xhdr.serial0 = xhdr.count;
+				xhdr.count = 0;
+			}
 
+			/*
+			 * Check that xhdr is consistent.
+			 */
+			if (xhdr.serial0 != serial ||
+			    isc_serial_le(xhdr.serial1, xhdr.serial0)) {
+				CHECK(ISC_R_UNEXPECTED);
+			}
+
+			/*
+			 * Extract record count from the transaction.  This
+			 * is needed when converting from XHDR_VERSION1 to
+			 * XHDR_VERSION2, and when recovering from an
+			 * incorrectly written XHDR_VERSION2.
+			 */
 			count = rrcount(buf, size);
 			CHECK(journal_write_xhdr(j2, xhdr.size, count,
 						 xhdr.serial0, xhdr.serial1));
