@@ -1,8 +1,6 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -11,7 +9,8 @@
  * information regarding copyright ownership.
  */
 
-#pragma once
+#ifndef GENERIC_HINFO_13_H
+#define GENERIC_HINFO_13_H 1
 
 typedef struct dns_rdata_hinfo {
 	dns_rdatacommon_t common;
@@ -21,3 +20,5 @@ typedef struct dns_rdata_hinfo {
 	uint8_t cpu_len;
 	uint8_t os_len;
 } dns_rdata_hinfo_t;
+
+#endif /* GENERIC_HINFO_13_H */
